Spreadsheet Metadata Workflow
=============================

It is possible to create Kolibri channels by specifying all the channel metadata
in the form of spreadsheet or CSV files instead of through Python code.


.. toctree::
   :maxdepth: 1

   csv_workflow
   csv_exercises
